@@ -13,14 +13,10 @@
 
 // Qt
 #include <QObject>
-#include <QList>
 
 // Marble
 #include <marble_export.h>
 
-class QString;
-class QImage;
-
 namespace Marble
 {
 class CountryByFlagPrivate;
@@ -30,7 +26,7 @@ class MARBLE_EXPORT CountryByFlag : public QObject
 {
     Q_OBJECT;
 public:
-    CountryByFlag( MarbleWidget *marbleWidget );
+    explicit CountryByFlag( MarbleWidget *marbleWidget );
     ~CountryByFlag();
 
 public Q_SLOTS:
