@@ -18,10 +18,7 @@
 #include <GeoDataLineString.h>
 #include <marble/LayerInterface.h>
 
-#include <QTime>
-#include <QTimer>
 #include <QApplication>
-#include <QKeyEvent>
 
 namespace Marble {
 
@@ -31,7 +28,7 @@ class MyPaintLayer : public QObject, public LayerInterface
 
 public:
     // Constructor
-    MyPaintLayer( MarbleWidget* widget );
+    explicit MyPaintLayer( MarbleWidget* widget );
 
     // LayerInterface
     QStringList renderPosition() const;
