@@ -13,13 +13,12 @@
 #include <QFile>
 #include <QDir>
 #include <QLocale>
-#include <QSettings>
 #include <QTranslator>
-#include <QProcessEnvironment>
 
 #include "QtMainWindow.h"
 
 #include "MapThemeManager.h"
+#include "MarbleWidgetInputHandler.h"
 #include "MarbleDirs.h"
 #include "MarbleDebug.h"
 #include "MarbleTest.h"
@@ -51,6 +50,7 @@ int main(int argc, char *argv[])
     QTranslator  translator;
     translator.load( "marble-" + lang, MarbleDirs::path(QString("lang") ) );
     app.installTranslator(&translator);
+    app.setApplicationDisplayName(MainWindow::tr("Marble - Virtual Globe"));
 
     // For non static builds on mac and win
     // we need to be sure we can find the qt image
@@ -112,6 +112,7 @@ int main(int argc, char *argv[])
         qWarning() << "  --runtimeTrace.............. Show the time spent and other debug info of each layer";
         qWarning() << "  --tile-id................... Write the identifier of texture tiles on top of them";
         qWarning() << "  --timedemo ................. Measure the paint performance while moving the map and quit";
+        qWarning() << "  --debug-polygons .............Display the polygon nodes and their index for debugging";
         qWarning();
         qWarning() << "profile options (note that marble should automatically detect which profile to use. Override that with the options below):";
         qWarning() << "  --highresolution ........... Enforce the profile for devices with high resolution (e.g. desktop computers)";
@@ -242,9 +243,16 @@ int main(int argc, char *argv[])
         else if( arg == "--runtimeTrace" ) {
             window->marbleControl()->marbleWidget()->setShowRuntimeTrace( true );
         }
+        else if( arg == "--debug-polygons" ) {
+            window->marbleControl()->marbleWidget()->setShowDebugPolygons( true );
+        }
         else if ( i != dataPathIndex && QFile::exists( arg ) )
             window->addGeoDataFile( arg );
     }
 
+    auto const marbleWidget = window->marbleControl()->marbleWidget();
+    bool const debugModeEnabled = marbleWidget->showRuntimeTrace() || marbleWidget->showDebugPolygons() || MarbleDebug::isEnabled();
+    marbleWidget->inputHandler()->setDebugModeEnabled(debugModeEnabled);
+
     return app.exec();
 }
