@@ -45,7 +45,7 @@ public:
 
     int m_iconSize;
 
-    MarbleLineEditPrivate( MarbleLineEdit* parent );
+    explicit MarbleLineEditPrivate( MarbleLineEdit* parent );
 
     void createProgressAnimation();
 };
@@ -147,7 +147,7 @@ void MarbleLineEdit::updateClearButtonIcon( const QString& text )
     }
 
     QString const direction = layoutDirection() == Qt::LeftToRight ? "rtl" : "ltr";
-    int const size = MarbleGlobal::getInstance()->profiles() & MarbleGlobal::SmallScreen ? 32 : 16;
+    int const size = (MarbleGlobal::getInstance()->profiles() & MarbleGlobal::SmallScreen) ? 32 : 16;
     QPixmap pixmap = QPixmap( QString( ":/icons/%1x%1/edit-clear-locationbar-%2.png").arg( size ).arg( direction ) );
     d->m_clearButton->setPixmap( pixmap );
 }
