@@ -15,7 +15,9 @@
 #include "marble_export.h"
 
 #include <QDialog>
-#include <QDialogButtonBox>
+
+class QDialogButtonBox;
+class QAbstractButton;
 
 namespace Marble {
 
@@ -40,14 +42,14 @@ public:
     explicit ConflictDialog( QWidget *parent = 0 );
     void setMergeItem( MergeItem *item );
 
-public slots:
+public Q_SLOTS:
     void open();
     void stopAutoResolve();
 
-signals:
+Q_SIGNALS:
     void resolveConflict( MergeItem *mergeItem );
 
-private slots:
+private Q_SLOTS:
     void resolveConflict( QAbstractButton *button );
 
 private:
