@@ -46,7 +46,7 @@ class BBCItemGetter : public AbstractWorkerThread
     void work();
 
  Q_SIGNALS:
-    void foundStation( BBCStation );
+    void foundStation( const BBCStation& );
 
  public:
     QList<BBCStation> m_items;
