@@ -20,7 +20,7 @@ namespace Marble
 class HostipPlugin : public SearchRunnerPlugin
 {
     Q_OBJECT
-    Q_PLUGIN_METADATA( IID "org.kde.edu.marble.HostipPlugin" )
+    Q_PLUGIN_METADATA(IID "org.kde.marble.HostipPlugin")
     Q_INTERFACES( Marble::SearchRunnerPlugin )
 
 public:
