@@ -37,7 +37,6 @@
 #include "GeoDataLatLonAltBox.h"
 #include "GeoDataCoordinates.h"
 
-#include <QCoreApplication>
 #include <QPointF>
 #include <QString>
 #include <QStringList>
@@ -50,8 +49,8 @@ class TestGeoDataCopy : public QObject
 {
     Q_OBJECT
     private:
-        void testCoordinate( GeoDataCoordinates coord, qreal alt, int detail, QString coordtest );
-    private slots:
+        void testCoordinate(GeoDataCoordinates coord, qreal alt, quint8 detail, QString coordtest );
+    private Q_SLOTS:
         void initTestCase();
         // misc.:
         void copyCoordinates();
@@ -87,7 +86,7 @@ class TestGeoDataCopy : public QObject
         GeoDataPoint point3;
 };
 
-void TestGeoDataCopy::testCoordinate( GeoDataCoordinates coord, qreal alt, int detail, QString coordtest )
+void TestGeoDataCopy::testCoordinate( GeoDataCoordinates coord, qreal alt, quint8 detail, QString coordtest )
 {
     QCOMPARE(coord.altitude(), alt);
     QCOMPARE(coord.detail(), detail);
@@ -156,8 +155,8 @@ void TestGeoDataCopy::copyPoint()
     
     point = GeoDataPoint( GeoDataCoordinates(13.7107, 51.0235, 123.4, GeoDataCoordinates::Degree, 17) );
     point.setExtrude(false);
-    QCOMPARE(other.coordinates().detail(), 2);
-    QCOMPARE(point.coordinates().detail(), 17);
+    QCOMPARE(other.coordinates().detail(), quint8(2));
+    QCOMPARE(point.coordinates().detail(), quint8(17));
     QCOMPARE(other.extrude(), true);
     QCOMPARE(point.extrude(), false);
 }
