@@ -25,7 +25,7 @@ class TestGeometryDetach : public QObject
 {
     Q_OBJECT
 
-private slots:
+private Q_SLOTS:
     void initTestCase();
 
     /**
